@@ -943,7 +943,7 @@ def kinematic_scattering(tags, verbose=False):
         if possible in ls:
             dynamic_allowed[ls.index(possible)] = True
 
-    dynamic_allowed = np.array(dynamic_allowed)
+    dynamic_allowed = np.array(dynamic_allowed, dtype=int)
     tags['dynamical allowed'] = {}
     tags['dynamical allowed']['Sg'] = s_g_forbidden[dynamic_allowed]
     tags['dynamical allowed']['hkl'] = hkl_forbidden[dynamic_allowed]
